@@ -56,8 +56,14 @@ utils::globalVariables(c("Country",
                          "SE.proportion_Public",
                          "Public.SE",
                          "Commercial_medical.SE",
-                         "SE.proportion_Public",
                          "Other.SE",
+                         "se.Public",
+                         "se.Commercial_medical",
+                         "se.Other",
+                         "Other_n",
+                         "Public_n",
+                         "Commercial_medical_n",
+                         "row_id",
                          "max.Other.SE",
                          "max.Public.SE",
                          "max.Commercial_medical.SE",
@@ -71,4 +77,7 @@ utils::globalVariables(c("Country",
                          "P",
                          "prop_max",
                          "prop_min",
-                         "index_subnat" ))
+                         "index_subnat",
+                         "mod",
+                         "sample_id",
+                         "p_samp"))
